
############
Contribution
############


HexWatershed was developed and maintainced by

* Chang Liao (Pacific Northwest National Laboratory)



If you are interested in contributing, join the Slack community: Slack_.

.. _Slack: https://hexwatershed.slack.com/

Please fill out the Form_.

.. _Form: https://forms.gle/kuXDS4LkJUaAQvH7A.

If you have trouble opening the Google Form, please send an email to changliao.climate@gmail.com with Subject "Join HexWatershed Slack", and please provide Name, Preferred Email, and Affiliation.
